utils.specutils_jwst package
============================

jwstspectrum
--------------------------------------

.. automodule:: utils.specutils_jwst.jwstspectrum
    :members:
    :undoc-members:
    :show-inheritance:

plotspec
-----------------------------------

.. autofunction:: utils.specutils_jwst.plotspec

readspec
-----------------------------------

.. autofunction:: utils.specutils_jwst.readspec
